﻿using System;
using System.Linq;
using Dynamicweb.Samples.Web.Model;
using Dynamicweb.Controls;

namespace Dynamicweb.Samples.Web.CustomModules.DvkArticles.Admin
{
	public partial class Default : System.Web.UI.Page
	{
		protected void Page_Init(object sender, EventArgs e)
		{
			deleteButton.Click += deleteButton_Click;
		}

		protected void Page_Load(object sender, EventArgs e)
		{
			if (!Page.IsPostBack)
			{
				//Prepopulate the Editor with the IntroText if available.
				using (CustomModulesSamplesEntities context = new CustomModulesSamplesEntities())
				{
					SiteSetting mySettings = context.SiteSettings.FirstOrDefault();
					if (mySettings != null)
					{
						IntroText.Text = mySettings.IntroText;
					}
				}
			}
		}

		/// <summary>
		/// Copies the selected articles.
		/// </summary>
		protected void copyButton_Click(object sender, EventArgs e)
		{
			string[] articleIds = Request.Form["ArticleId"].Split(new char[] { ',' });
			using (CustomModulesSamplesEntities context = new CustomModulesSamplesEntities())
			{
				foreach (string item in articleIds)
				{
					int articleId = Convert.ToInt32(item);
					Article article = context.Articles.Include("Category").Where(a => a.Id == articleId).FirstOrDefault();
					if (article != null)
					{
						Article newArticle = new Article()
						{
							Body = article.Body,
							Category = article.Category,
							CreateDateTime = article.CreateDateTime,
							Deleted = article.Deleted,
							PublicationDateFrom = article.PublicationDateFrom,
							PublicationDateTo = article.PublicationDateTo,
							SeoDescription = article.SeoDescription,
							Summary = article.Summary,
							Title = "Copy of " + article.Title,
							UpdateDateTime = article.UpdateDateTime,
							CssClass = article.CssClass,
							Published = false
						};

						context.AddToArticles(newArticle);
					}
				}
				context.SaveChanges();
				ArticleList.DataBind();
			}
		}

		/// <summary>
		/// Copies the selected articles.
		/// </summary>
		protected void deleteButton_Click(object sender, EventArgs e)
		{
			string[] articleIds = Request.Form["ArticleId"].Split(new char[] { ',' });
			using (CustomModulesSamplesEntities context = new CustomModulesSamplesEntities())
			{
				foreach (string item in articleIds)
				{
					int articleId = Convert.ToInt32(item);
					Article article = context.Articles.Where(a => a.Id == articleId).FirstOrDefault();
					if (article != null)
					{
						article.Deleted = true;
					}
				}
				context.SaveChanges();
				ArticleList.DataBind();
			}
		}

		/// <summary>
		/// Stores the IntroText in the database
		/// </summary>
		protected void saveButton_Click(object sender, EventArgs e)
		{
			using (CustomModulesSamplesEntities context = new CustomModulesSamplesEntities())
			{
				SiteSetting mySettings = context.SiteSettings.FirstOrDefault();
				if (mySettings == null)
				{
					mySettings = new SiteSetting();
					context.AddToSiteSettings(mySettings);
				}
				mySettings.IntroText = IntroText.Text;
				context.SaveChanges();
			}
		}
	}
}